@@ -20,6 +20,7 @@ sub handle {
 	die UvT::Kiki::ACL::Document(req => $req)->new->response
  		unless $req->authorized;
 	my $res = super($req, @_);
-	$res->setcookie(session => $req->session) unless $req->cur_session;
+	$res->setcookie(session => $req->session, HttpOnly => 1, Secure => $req->secure)
+		unless $req->cur_session;
 	return $res;
 }
